Skip to contents

Expect autotest_package() to be clear of errors with some tests switched off, and to have note column explaining why those tests are not run.

Usage

expect_autotest_testdata(object)

Arguments

object

An autotest_package object with a test column flagging tests which are not to be run on the local package.

Value

(invisibly) The autotest object

Examples

test_data <- autotest_types (notest = "vector_to_list_col")
if (FALSE) { # \dontrun{
# Called within a 'testthat' test file of the local package itself:
testthat::test_that ("autotest", {
    testthat::expect_success (expect_autotest_testdata (test_data))
})
} # }