autotest-package: autotest: Automatic Package Testing

autotest-packageR Documentation

autotest: Automatic Package Testing

Description

Automatic testing of R packages by tracing function calls made in examples and tests, then systematically varying the inputs to check that functions respond sensibly.

Author(s)

Maintainer: Mark Padgham mark.padgham@email.com (ORCID)

Authors:

Other contributors:

  • Jouni Helske (ORCID) [contributor]

See Also

Useful links:


autotest documentation built on Sept. 12, 2026, 5:10 p.m.