| autotest-package | R Documentation |
Automatic testing of R packages by tracing function calls made in examples and tests, then systematically varying the inputs to check that functions respond sensibly.
Maintainer: Mark Padgham mark.padgham@email.com (ORCID)
Authors:
Mark Padgham mark.padgham@email.com (ORCID)
Other contributors:
Jouni Helske (ORCID) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.