Learn R Programming

autotest (version 0.2.0)

autotest-package: autotest: Automatic Package Testing

Description

Automatic testing of R packages by tracing function calls made in examples and tests, then systematically varying the inputs to check that functions respond sensibly.

Arguments

Author

Maintainer: Mark Padgham [email protected] (ORCID)

Authors:

Other contributors:

  • Jouni Helske (ORCID) [contributor]

See Also