Automatic testing of R packages by tracing function calls made in examples and tests, then systematically varying the inputs to check that functions respond sensibly.
Maintainer: Mark Padgham [email protected] (ORCID)
Authors:
Mark Padgham [email protected] (ORCID)
Other contributors:
Jouni Helske (ORCID) [contributor]