powered by
This function exists only to provide the class definitions for test objects, and is not intended to be called directly.
autotest_obj( package = NA_character_, package_loc = NULL, test_name = NA_character_, fn_name = NA_character_, parameters = list(), parameter_types = NA_character_, class = NULL, classes = NULL, env = new.env(), test = FALSE, quiet = FALSE )
An object of class autotest_obj, a list holding the parameters passed as arguments, used internally to represent one autotest test case.
autotest_obj
Name of package for which object is to be constructed.
Location of package on local system (for source packages only)
Name of test (use autotest_types to get all test names).
Name of function to be tested.
Names of all parameters for that function.
Types of input parameters.
Class of an individual parameter.
Classes of all parameters.
Environment in which tests are to be run.
If FALSE, return only descriptions of tests which would be run with test = TRUE, without actually running them.
FALSE
test = TRUE
If FALSE, issue progress and other messages during testing of object.
x <- autotest_obj ( package = "stats", fn_name = "sd", test_name = "test" )
Run the code above in your browser using DataLab