List all types of 'autotests' currently implemented.
Usage
autotest_types(notest = NULL)
Value
An autotest object with each row listing one unique type of test
which can be applied to every parameter (of the appropriate class) of each
function.
Arguments
notest
Character string of names of tests which should be switched off
by setting the test column to FALSE. Run this function first without this
parameter to get all names, then re-run with this parameter switch specified
tests off.