Expect autotest_package() to be clear of errors with some tests switched
off, and to have note column explaining why those tests are not run.
See also
Other expectations:
expect_autotest_no_err(),
expect_autotest_no_testdata(),
expect_autotest_no_warn(),
expect_autotest_notes()
Examples
test_data <- autotest_types (notest = "vector_to_list_col")
if (FALSE) { # \dontrun{
# Called within a 'testthat' test file of the local package itself:
testthat::test_that ("autotest", {
testthat::expect_success (expect_autotest_testdata (test_data))
})
} # }