| expect_autotest_testdata | R Documentation |
Expect autotest_package() to be clear of errors with some tests switched
off, and to have note column explaining why those tests are not run.
expect_autotest_testdata(object)
object |
An |
(invisibly) The autotest object
Other expectations:
expect_autotest_no_err(),
expect_autotest_no_testdata(),
expect_autotest_no_warn(),
expect_autotest_notes()
test_data <- autotest_types (notest = "vector_to_list_col")
## Not run:
# Called within a 'testthat' test file of the local package itself:
testthat::test_that ("autotest", {
testthat::expect_success (expect_autotest_testdata (test_data))
})
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.